@@ -50,7 +50,7 @@ class DriveSerializer(NetBoxModelSerializer):
 class PartitionSerializer(serializers.ModelSerializer):
     url = serializers.HyperlinkedIdentityField(view_name='plugins-api:netbox_storage-api:partition-detail')
     drive = NestedDriveSerializer(required=False, allow_null=True)
-    device = NestedLinuxDeviceSerializer(required=False, allow_null=True)
+    fs_type = NestedFilesystemSerializer(required=False, allow_null=True)
 
     class Meta:
         model = Partition
@@ -58,9 +58,9 @@ class PartitionSerializer(serializers.ModelSerializer):
             "id",
             "url",
             "drive",
-            "device",
             "size",
-            "type",
+            "fs_type",
+            "letter",
             "description",
             "created",
             "last_updated",
