@@ -6,14 +6,9 @@ from netbox_storage.models import VolumeGroup
 
 
 class VolumeGroupFilter(NetBoxModelFilterSet):
-    """Filter capabilities for VolumeGroup instances."""
-
     class Meta:
         model = VolumeGroup
-        fields = [
-            "vg_name",
-            "description"
-        ]
+        fields = ["vg_name", "description"]
 
     def search(self, queryset, name, value):
         """Perform the filtered search."""
@@ -21,5 +16,6 @@ class VolumeGroupFilter(NetBoxModelFilterSet):
             return queryset
         qs_filter = (
             Q(vg_name__icontains=value)
+            |Q(description__icontains=value)
         )
         return queryset.filter(qs_filter)
