@@ -25,7 +25,7 @@ class PhysicalVolumeForm(NetBoxModelForm):
         help_text="Short Description e.g. PhysicalVolume 1 on SSD Cluster",
     )
     linux_device = DynamicModelChoiceField(
-        queryset=LinuxDevice.objects.all(),
+        queryset=LinuxDevice.objects.filter(type='Partition'),
         label="Linux Device",
         help_text="The parent Object of the Device e.g. Drive, LinuxDevice, LV",
     )
