@@ -10,6 +10,7 @@ from dcim.models import Platform
 from netbox.forms import (
     NetBoxModelForm,
 )
+from netbox_storage.choices import DeviceTypeChoices
 from netbox_storage.models import Drive, Filesystem, Partition, PhysicalVolume, VolumeGroup, LogicalVolume, \
     MountedVolume, LinuxDevice, TemplateConfigurationDrive
 from utilities.forms import (
@@ -244,6 +245,7 @@ class PartitionTemplateForm(NetBoxModelForm):
         required=False,
         label="FS Options",
         help_text="The mounted point of the volume e.g. /var/lib/docker",
+        initial='defaults',
     )
     label = CharField(
         required=False,
@@ -288,18 +290,31 @@ class PartitionTemplateForm(NetBoxModelForm):
         ]
 
     def save(self, *args, **kwargs):
-        print(f"drive: {self.cleaned_data['drive']}")
-        new_partition_count = Partition.objects.filter(drive_id=self.cleaned_data['drive'].id).count() + 1
-        device_name_prefix = Drive.objects.get(pk=self.cleaned_data['drive'].id).device_name()
+        # Drive Object
+        drive = Drive.objects.get(pk=self.cleaned_data['drive'].id)
+
+        # Drive Type ID
+        drive_type_id = ContentType.objects.get(app_label='netbox_storage', model='drive').pk
+
+        # All linux devices, which are partition and have the drive as a parent object
+        linux_device_partitions = LinuxDevice.objects.filter(content_type_id=drive_type_id,
+                                                             object_id=drive.pk,
+                                                             type=DeviceTypeChoices.CHOICE_PARTITION)
+
+        new_partition_count = linux_device_partitions.count() + 1
+        device_name_prefix = drive.device_name()
         print(f"Partition Count: {new_partition_count}")
         print(f"Device Name: {device_name_prefix}")
         device_name = device_name_prefix + str(new_partition_count)
 
         linux_device_type_pk = ContentType.objects.get(app_label='netbox_storage', model='linuxdevice').pk
+        drive_type_pk = ContentType.objects.get(app_label='netbox_storage', model='drive').pk
+
+        linux_device_drive = LinuxDevice.objects.get(object_id=drive.pk,content_type_id=drive_type_pk)
 
         self.instance.device = device_name
         self.instance.type = 'Partition'
-        self.instance.object_id = self.cleaned_data['drive'].pk
+        self.instance.object_id = linux_device_drive.pk
         self.instance.content_type_id = linux_device_type_pk
         linux_device_partition = super().save(*args, **kwargs)
 
