@@ -15,13 +15,13 @@ class PartitionTable(NetBoxTable):
     drive = tables.Column(
         linkify=True
     )
-    device = tables.Column(
+    letter = tables.Column(
         linkify=True
     )
     size = tables.Column(
         linkify=True
     )
-    type = tables.Column(
+    fs_type = tables.Column(
         linkify=True
     )
 
@@ -30,13 +30,14 @@ class PartitionTable(NetBoxTable):
         fields = (
             "pk",
             "drive",
-            "device",
+            "letter",
             "size",
+            'fs_type',
             "description",
         )
         default_columns = (
-            "device",
+            "letter",
             "size",
-            "type",
+            "fs_type",
             "description",
         )
